@@ -1,11 +1,10 @@
 import cv2 as cv
 from numpy import append
-import numpy as np
-import DetectedArea
-import DetectedFace
-import ImageManager
-import Point
-import HelperFunctions
+from . import DetectedArea
+from .DetectedArea import DetectedFace
+from . import ImageManager
+from . import Point
+from .helperFunctions import *
 import time
 import threading
 import queue
@@ -61,7 +60,7 @@ class VideoManager:
                 break
             # Our operations on the frame come here
             start = time.time()
-            frame = HelperFunctions.resizeMinTo500(frame)
+            frame = resizeMinTo500(frame)
             print(f"DEBUG resize time {time.time() - start}")
 
             # Display the resulting frame
@@ -132,7 +131,7 @@ class VideoManager:
                 # Our operations on the frame come here
                 debug_frameCount = debug_frameCount + 1
 
-                frame = HelperFunctions.resizeMinTo500(frame)
+                frame = resizeMinTo500(frame)
 
                 # startTime = time.time()
                 grayFrame = cv.cvtColor(frame, cv.COLOR_BGR2GRAY)
@@ -216,7 +215,7 @@ class VideoManager:
                 # Our operations on the frame come here
                 debug_frameCount = debug_frameCount + 1
 
-                frame = HelperFunctions.resizeMinTo500(frame)
+                frame = resizeMinTo500(frame)
                 frameMgnr = ImageManager(frame)
                 # startTime = time.time()
                 faces = frameMgnr.findFacesCounterClockwiseMultipleAngles(
@@ -297,7 +296,7 @@ class VideoManager:
                     continue
 
                 # resizing the frame to fit my tiny monitor, and to increase haarcascade detection performance too ye
-                frame = HelperFunctions.resizeMinTo500(frame)
+                frame = resizeMinTo500(frame)
 
                 # set new display time target (next_frame) after check if new frame is available instead of before. This is to make sure when live capturing
                 # the newest image will be shown as soon as they are ready (variable fps maybe). If this was to be put before checking if new frame is available, newest
@@ -407,7 +406,7 @@ class VideoManager:
                 
                 startTime = time.time()
                 # resizing the frame to fit my tiny monitor, and to increase haarcascade detection performance too ye
-                min500frame = HelperFunctions.resizeMinTo500(frame)
+                min500frame = resizeMinTo500(frame)
                 resizeTime = time.time() - startTime
 
                 # set new display time target (next_frame) after check if new frame is available instead of before. This is to make sure when live capturing
@@ -502,7 +501,7 @@ class VideoManager:
                             # rotate clockwise because the face's angle is the counter clockwise angle of the right eye to the left eye
                             frameOrigin = Point(
                                 min500frame.shape[1]/2, min500frame.shape[0]/2)
-                            rotatedFrame = HelperFunctions.rotateClockwise(
+                            rotatedFrame = rotateClockwise(
                                 min500frame, counterClockwiseAngle)
                             rotatedFrameOrigin = Point(
                                 rotatedFrame.shape[1]/2, rotatedFrame.shape[0]/2)
@@ -549,7 +548,7 @@ class VideoManager:
                                 croppedPotentialFace, cv.COLOR_BGR2GRAY)
                             # run basic haarcascade facial detection on it
                             # CAN IMPROVE PERFORMANCE BY ADDING APPROPRIATE MINSIZE AND MAXSIZE ? CAN IMPROVE PERFORMANCE BY ADDING APPROPRIATE MINSIZE AND MAXSIZE ? CAN IMPROVE PERFORMANCE BY ADDING APPROPRIATE MINSIZE AND MAXSIZE ?
-                            detectedFaces = HelperFunctions.haarcascade_FacialDetection(
+                            detectedFaces = haarcascade_FacialDetection(
                                 grayCroppedPotentialFace, 1.3, 6)
 
                             # if found nothing then move to the next face's last frame location
@@ -592,7 +591,7 @@ class VideoManager:
                             # CAN IMPROVE PERFORMANCE BY ADDING APPROPRIATE MINSIZE AND MAXSIZE ? CAN IMPROVE PERFORMANCE BY ADDING APPROPRIATE MINSIZE AND MAXSIZE ? CAN IMPROVE PERFORMANCE BY ADDING APPROPRIATE MINSIZE AND MAXSIZE ?
 
                             # find the eyes
-                            tempEyesArray = HelperFunctions.haarcascade_EyeDetection(
+                            tempEyesArray = haarcascade_EyeDetection(
                                 grayCroppedPotentialFace, 1.3, 10)
                             detectedEyes = []
 
