@@ -1,13 +1,10 @@
 import cv2 as cv
 from numpy import append
-import DetectedArea
-import DetectedFace
-import ImageManager
-import Point
-import HelperFunctions
-import time
-import threading
-import queue
+from . import DetectedArea
+# from .DetectedArea import DetectedFace
+from . import ImageManager
+from . import Point
+from .helperFunctions import *
 
 
 class VideoManagerForServer:
@@ -42,7 +39,7 @@ class VideoManagerForServer:
 
         
         # Our operations on the frame come here
-        frame = HelperFunctions.resizeMinTo500(frame)
+        frame = resizeMinTo500(frame)
 
         # startTime = time.time()
         grayFrame = cv.cvtColor(frame, cv.COLOR_BGR2GRAY)
